@@ -1,7 +1,7 @@
 from importlib import import_module
 from pprint import pformat
-
 from datetime import datetime
+
 from floraconcierge import errors
 
 
@@ -56,5 +56,8 @@ class Object(object):
     def __repr__(self):
         return '<%s %s>' % (self.__class__.__name__, pformat(self.__dict__))
 
+    def todict(self):
+        return self.__dict__
+
     def datetime(self, unixtime):
         return datetime.fromtimestamp(int(unixtime))
